import { validate } from "jsonschema";
import { wrapFunction } from "./wrapper.js";
import createError from "@fastify/error";
const ValidationError = createError("VALIDATION_ERROR", "Input is invalid on property path %s", 400);
const wrapFunctionWithSchema = (logic, schema) => async (args) => {
  async function wrappedValidationLogic(innerArgs) {
    const valid = validate(innerArgs, schema);
    if (!innerArgs) {
      throw new ValidationError("$ (root)");
    } else if (valid.valid) {
      return await logic(innerArgs);
    } else {
      throw new ValidationError(valid.propertyPath);
    }
  }
  return await wrapFunction(wrappedValidationLogic)(args);
};
export {
  wrapFunctionWithSchema
};
